@@ -63,7 +63,7 @@ file_theme_type(gchar *dir)
 {
 	gchar *file_contents;
 	gchar *filename = NULL;
-	gint file_size;
+	gint file_size, theme_type;
 	GPatternSpec *pattern;
 	char *uri;
 	GnomeVFSURI *src_uri;
@@ -98,6 +98,7 @@ file_theme_type(gchar *dir)
 		gnome_vfs_uri_unref (src_uri);
 		return THEME_GTK;
 	}
+        gnome_vfs_uri_unref (src_uri);
 	
 	filename = g_strdup_printf ("%s/metacity-1/metacity-theme-1.xml",dir);
 	src_uri = gnome_vfs_uri_new (filename);
@@ -106,6 +107,7 @@ file_theme_type(gchar *dir)
 		gnome_vfs_uri_unref (src_uri);
 		return THEME_METACITY;
 	}
+        gnome_vfs_uri_unref (src_uri);
 	
 	
 	filename = g_strdup_printf ("%s/configure.in",dir);
@@ -115,6 +117,7 @@ file_theme_type(gchar *dir)
 		gnome_vfs_uri_unref (src_uri);
 		return THEME_ENGINE;
 	}
+        gnome_vfs_uri_unref (src_uri);
 	
 	return THEME_INVALID;
 }
@@ -224,7 +227,7 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 
 	gtk_widget_destroy (dlg);
 	
-	theme_props = g_new(theme_properties,1);
+	theme_props = g_new0 (theme_properties,1);
 	
 	theme_props->target_tmp_dir = g_strdup_printf ("%s/.themes/.theme-%u", 
 				 			g_get_home_dir(), 
@@ -237,13 +240,13 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
   	
  	if (tar && gzip && path && len > 7 && ( (!strcmp (path + len - 7, ".tar.gz")) || (!strcmp (path + len - 4, ".tgz")) )) {
   		filename = g_shell_quote (path);
- 		command = g_strdup_printf ("sh -c '%s -d -c < \"%s\" | %s ft -  | head -1'",
+ 		command = g_strdup_printf ("sh -c '%s -d -c < \"%s\" | %s ft -  | head -n 1'",
  					    gzip, filename, tar);
   		theme_props->filetype=TARGZ;
   		g_free (filename);
  	} else if (tar && bzip2 && path && len > 8 && !strcmp (path + len - 8, ".tar.bz2")) {
   		filename = g_shell_quote (path);
- 		command = g_strdup_printf ("sh -c '%s -d -c < \"%s\" | %s ft - | head -1'",
+ 		command = g_strdup_printf ("sh -c '%s -d -c < \"%s\" | %s ft - | head -n 1'",
  					    bzip2, filename, tar);
 		theme_props->filetype=TARBZ;
 		g_free (filename);
@@ -449,8 +452,8 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 			if (theme_type == THEME_GTK || theme_type == THEME_METACITY || theme_type == THEME_ICON)
 			{
 				/* TODO: currently cannot apply "gnome themes" */
-				theme_props->user_message=g_strdup_printf(_("The theme \"%s\" has been installed.\nWould you like to apply it now, or keep your current theme?"),dir[0]);
-				dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, theme_props->user_message );
+				theme_props->user_message=g_strdup_printf(_("<span weight=\"bold\" size=\"larger\">The theme \"%s\" has been installed.</span>\n\nWould you like to apply it now, or keep your current theme?"),dir[0]);
+				dialog = gtk_message_dialog_new_with_markup (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, theme_props->user_message );
 
 				gtk_dialog_add_button (GTK_DIALOG (dialog), _("Keep Current Theme"), GTK_RESPONSE_CLOSE);
 
@@ -669,19 +672,6 @@ gnome_theme_installer_run (GtkWindow *parent, gchar *filename)
 
 	running_theme_install = TRUE;
 
-	if (!g_file_test ("/bin/tar", G_FILE_TEST_EXISTS)) {
-		GtkWidget *error_dialog;
-
-		error_dialog = gtk_message_dialog_new (NULL,
-						GTK_DIALOG_MODAL,
-						GTK_MESSAGE_ERROR,
-						GTK_BUTTONS_OK,
-						_("Cannot install theme.\nThe tar program is not installed on your system."));
-		gtk_dialog_run (GTK_DIALOG (error_dialog));
-		gtk_widget_destroy (error_dialog);
-		return;
-	}
-
 	dialog = gtk_file_chooser_dialog_new ("Select Theme", parent, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), old_folder);
