@@ -1,4 +1,4 @@
-/* $Id: keyboard-drawing.h,v 1.15 2004/10/24 21:01:25 svu Exp $ */
+/* $Id: keyboard-drawing.h 105 2005-11-14 15:18:08Z kmaraas $ */
 /*
  * keyboard-drawing.h: header file for a gtk+ widget that is a drawing of
  * the keyboard of the default display
@@ -43,6 +43,7 @@ typedef struct _KeyboardDrawingClass  KeyboardDrawingClass;
 typedef struct _KeyboardDrawingItem   KeyboardDrawingItem;
 typedef struct _KeyboardDrawingKey    KeyboardDrawingKey;
 typedef struct _KeyboardDrawingDoodad KeyboardDrawingDoodad;
+typedef struct _KeyboardDrawingGroupLevel KeyboardDrawingGroupLevel;
 
 typedef enum 
 { 
@@ -51,6 +52,20 @@ typedef enum
 } 
 KeyboardDrawingItemType;
 
+typedef enum
+{
+  KEYBOARD_DRAWING_POS_TOPLEFT,
+  KEYBOARD_DRAWING_POS_TOPRIGHT,
+  KEYBOARD_DRAWING_POS_BOTTOMLEFT,
+  KEYBOARD_DRAWING_POS_BOTTOMRIGHT,
+  KEYBOARD_DRAWING_POS_TOTAL,
+  KEYBOARD_DRAWING_POS_FIRST =
+    KEYBOARD_DRAWING_POS_TOPLEFT,
+  KEYBOARD_DRAWING_POS_LAST =
+    KEYBOARD_DRAWING_POS_BOTTOMRIGHT,
+}
+KeyboardDrawingGroupLevelPosition;
+
 /* units are in xkb form */
 struct _KeyboardDrawingItem
 {
@@ -94,6 +109,11 @@ struct _KeyboardDrawingDoodad
   gboolean                 on; /* for indicator doodads */
 };
 
+struct _KeyboardDrawingGroupLevel
+{
+  gint                     group;
+  gint                     level;
+};
 
 struct _KeyboardDrawing
 {
@@ -103,6 +123,7 @@ struct _KeyboardDrawing
 
   GdkPixmap              *pixmap;
   XkbDescRec             *xkb;
+  gboolean                xkbOnDisplay;
 
   gint                    angle;  /* current angle pango is set to draw at, in tenths of a degree */
   PangoLayout            *layout;
@@ -120,11 +141,7 @@ struct _KeyboardDrawing
 
   guint                   timeout;
 
-  gint                    leftgroup;
-  gint                    rightgroup;
-
-  gint                    bottomlevel;
-  gint                    toplevel;
+  KeyboardDrawingGroupLevel ** groupLevels;
 
   guint                   mods;
 
@@ -137,7 +154,6 @@ struct _KeyboardDrawing
   gint                    physical_indicators_size;
 
   guint                   track_config : 1;
-  guint                   track_group : 1;
   guint                   track_modifiers : 1;
 };
 
@@ -152,14 +168,9 @@ struct _KeyboardDrawingClass
                         guint            keycode);
 };
 
-GType                 keyboard_drawing_get_type         ();
-GtkWidget *           keyboard_drawing_new              ();
-void                  keyboard_drawing_set_groups       (KeyboardDrawing      *kbdrawing, 
-                                                         gint                  leftgroup, 
-                                                         gint                  rightgroup);
-void                  keyboard_drawing_set_levels       (KeyboardDrawing      *kbdrawing, 
-                                                         gint                  bottomlevel, 
-                                                         gint                  toplevel);
+GType                 keyboard_drawing_get_type         (void);
+GtkWidget *           keyboard_drawing_new              (void);
+
 GdkPixbuf *           keyboard_drawing_get_pixbuf       (KeyboardDrawing      *kbdrawing);
 gboolean              keyboard_drawing_set_keyboard     (KeyboardDrawing      *kbdrawing, 
                                                          XkbComponentNamesRec *names);
@@ -170,13 +181,14 @@ G_CONST_RETURN gchar *keyboard_drawing_get_symbols      (KeyboardDrawing      *k
 G_CONST_RETURN gchar *keyboard_drawing_get_types        (KeyboardDrawing      *kbdrawing);
 G_CONST_RETURN gchar *keyboard_drawing_get_compat       (KeyboardDrawing      *kbdrawing);
 
-void                  keyboard_drawing_set_track_group  (KeyboardDrawing      *kbdrawing, 
-                                                         gboolean              enable);
 void                  keyboard_drawing_set_track_modifiers (KeyboardDrawing      *kbdrawing, 
                                                             gboolean              enable);
 void                  keyboard_drawing_set_track_config (KeyboardDrawing      *kbdrawing, 
                                                          gboolean              enable);
 
+void                  keyboard_drawing_set_groups_levels(KeyboardDrawing      *kbdrawing, 
+                                                         KeyboardDrawingGroupLevel * groupLevels[]);
+
 G_END_DECLS
 
 #endif /* #ifndef KEYBOARD_DRAWING_H */
